/*======================================================*
Purpose 	:	长期护理保险的资源配置效应
Data 1		: 	城市层面老年照护机构信息数据
Data 2		: 	长护险制度特征数据
Data 3		: 	城市统计年鉴数据
Created by	: 	zhangyieco@gmail.com
Last Modify : 	20241023
*=======================================================*/
	
	clear all
	set	more off
	set scrollbufsize 2048000
	capture log close 

	global replication "/Users/zhangyi/Desktop/replication"	
	global rawdata  "$replication/rawdata"
	global workingdata  "$replication/workingdata"
	global table  "$replication/output/table"
	global figure  "$replication/output/figure"
	cd "$replication" 

	use "$rawdata/TYC_2020_reg.dta",clear

*需要安装的外部命令
*	ssc install coefplot,replace 	//可视化回归系数
*	ssc install reghdfe,replace     // 面板回归
*	ssc install outreg2,replace 	// 输出汇总回归结果
*	ssc install ddtiming,replace  	// Goodman-Bacon分解
*	ssc install sum2docx,replace  //输出描述性统计表格

*变量说明
* city_code 		：城市代码
* prov_code			：省份代码
* year 				：年份

* ltc_time			：长护险试点年份
* jj_time 			：居家和社区养老服务改革试点

* type_3			：医疗类居家机构
* type_3_p			：营利性医疗类居家机构
* type_3_np			：非营利性医疗类居家机构
* nursing_home		：养老院
* nursing_home_p	：营利性养老院
* nursing_home_np	：非营利性养老院
* type_6			：社区照护机构
* pop				：年末总人口（万人）
* GDP				：地区生产总值（亿元）
* yszc				：一般公共预算支出（亿元）
* hospital			：医院、卫生院数量（个）
* hospital_bed		：医院、卫生院床位数（张）
* doctor			：执业或助理医师数（人）
* prov_old_ratio	：老年人抚养比（省级）

*===========Table 2 描述性统计=============*
*===========Table 2 描述性统计=============*
*===========Table 2 描述性统计=============*
	sum type_3 type_3_p type_3_np nursing_home nursing_home_p nursing_home_np type_6  pop GDP yszc hospital hospital_bed doctor , format
	sum2docx  type_3 type_3_p type_3_np nursing_home nursing_home_p nursing_home_np type_6 pop GDP yszc hospital hospital_bed doctor using "$table/sum1.docx", replace stats(N mean sd min  max) 

*省级老年人抚养比的描述性统计，省份层面变量
	preserve
	keep 省份 year prov_old_ratio
	duplicates drop 省份 year,force 
	sum prov_old_ratio
	sum2docx  prov_old_ratio using "$table/sum2.docx", replace stats(N mean sd min  max) 
	restore

	global control pop GDP yszc hospital hospital_bed doctor prov_old_ratio


*===============长护险试点的事件研究法-准备===============*
*===============长护险试点的事件研究法-准备===============*
*===============长护险试点的事件研究法-准备===============*
	gen event =year - ltc_time
	bro 市 year ltc_time event
	tab event,m
	*将试点前7期和试点后4期进行归并
	replace event = -7 	if event <= -7
	replace event = 4 	if event >=	4 & event!=.

	tab event, gen(ltc_)
	forvalues i = 1/12{
		replace ltc_`i' = 0 if ltc_`i' == .
	}

	label var ltc_1 	"<=-7" 
	label var ltc_2 	"-6" 
	label var ltc_3 	"-5" 
	label var ltc_4 	"-4" 
	label var ltc_5 	"-3" 
	label var ltc_6 	"-2" 
	label var ltc_7 	"-1" 
	label var ltc_8 	"0" 
	label var ltc_9 	"1" 
	label var ltc_10	"2" 
	label var ltc_11	"3" 
	label var ltc_12	">=4" 
	rename ltc_1 	ltc_p7
	rename ltc_2 	ltc_p6
	rename ltc_3 	ltc_p5
	rename ltc_4 	ltc_p4
	rename ltc_5 	ltc_p3
	rename ltc_6 	ltc_p2
	rename ltc_7 	ltc_p1
	rename ltc_8 	ltc_l0
	rename ltc_9 	ltc_l1
	rename ltc_10 	ltc_l2
	rename ltc_11 	ltc_l3
	rename ltc_12 	ltc_l4

*===============居家社区试点的事件研究法-准备===============*
*===============居家社区试点的事件研究法-准备===============*
*===============居家社区试点的事件研究法-准备===============*
	gen jj_event=year-jj_time
	label var jj_event "居家和社区综合改革试点"
	tab jj_event,m
	*将试点前7期和试点后4期进行归并
	replace jj_event = -7 	if jj_event <= -7
	replace jj_event = 4 	if jj_event >=	4 & jj_event!=.

	tab jj_event, gen(home_)
	forvalues i = 1/12{
		replace home_`i' = 0 if home_`i' == . 
	}

	label var home_1 	"<=-7" 
	label var home_2 	"-6" 
	label var home_3 	"-5" 
	label var home_4 	"-4" 
	label var home_5 	"-3" 
	label var home_6 	"-2" 
	label var home_7 	"-1" 
	label var home_8 	"0" 
	label var home_9 	"1" 
	label var home_10  	"2" 
	label var home_11  	"3" 
	label var home_12  	">=4" 
	
	rename home_1 	home_p7
	rename home_2 	home_p6
	rename home_3 	home_p5
	rename home_4 	home_p4
	rename home_5 	home_p3
	rename home_6 	home_p2
	rename home_7 	home_p1
	rename home_8 	home_l0
	rename home_9 	home_l1
	rename home_10 	home_l2
	rename home_11 	home_l3
	rename home_12 	home_l4

	global ltc_all ltc_p7 ltc_p6 ltc_p5 ltc_p4 ltc_p3 ltc_p2 ltc_p1 ltc_l0 ltc_l1 ltc_l2 ltc_l3 ltc_l4
	global home_all  home_p7 home_p6 home_p5 home_p4 home_p3 home_p2 home_p1 home_l0 home_l1 home_l2 home_l3 home_l4

*============== Figure 3 ================*
*============== Figure 3 ================*
*============== Figure 3 ================*

preserve
	replace ltc_p1=0
	reghdfe type_3 $ltc_all  $control  , absorb(city_code year i.prov_code#c.year )  vce(cluster city_code)
	estimates store reg_h
	reghdfe type_6 $ltc_all  $control  , absorb(city_code year i.prov_code#c.year)  vce(cluster city_code)
	estimates store reg_c
	reghdfe nursing_home $ltc_all  $control  , absorb(city_code year i.prov_code#c.year )  vce(cluster city_code)
	estimates store reg_nur
restore

coefplot (reg_h,omitted keep($ltc_all) label(医疗类居家机构) msymbol(S) mcolor(gs5) recast(rcap) color(pink) lp(thin) ciopts(recast(rcap) color(gs5)) ) ///
		 (reg_nur,omitted keep($ltc_all) label(养老院) msymbol(T) mcolor(gs5) recast(rcap) color(pink) lp(thin) ciopts(recast(rcap) color(gs5)) ) ///
		 (reg_c,omitted keep($ltc_all) label(社区照护机构) msymbol(D) mcolor(gs5) recast(rcap) color(pink) lp(thin) ciopts(recast(rcap) color(gs5)) ), ///
		vertical drop(_cons) ylabel(, nogrid) yline(0,lp(dash)) xline(6.5(.01)7.5, lcolor(gs14)) ///
		ylabel(-40(20)60, grid)  ytitle("事"	"件""分""析""法""估""计""结""果",size(9pt) angle(90) orientation(horizontal)) ///
		title("长护险试点的影响",size(10pt) color(black)) ///
		xtitle("相对于长护险实施的年份", size(9pt)) ///
		legend ( ring(0) pos(11) size(small) row(3)) ///
		graphregion(color(white)) //白底
		graph save "$figure/figure3.gph",replace 

*=========== Table3 Panel A =============*
*=========== Table3 Panel A =============*
*=========== Table3 Panel A =============*

*医疗护理+生活照料类机构	
	*医疗类居家机构	
	reghdfe type_3 treat_event $control , absorb(city_code year i.prov_code#c.year) vce(cluster city_code)
	sum   type_3    if LTC!=0  
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table3_panelA.doc",  keep(treat_event)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)    replace   
	*养老院
	reghdfe nursing_home treat_event $control , absorb(city_code year i.prov_code#c.year) vce(cluster city_code)
	sum   nursing_home if  LTC!=0 
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table3_panelA.doc",keep(treat_event)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)  append   
*生活照料类机构		
	*社区照护机构
	reghdfe type_6 treat_event $control , absorb(city_code year i.prov_code#c.year) vce(cluster city_code)
	sum   type_6    if LTC!=0 
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table3_panelA.doc",  keep(treat_event)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)    append   


*=========== Table3 Panel B =============*
*=========== Table3 Panel B =============*
*=========== Table3 Panel B =============*

*系数合并成0-2 和 3-4期，生成相应的虚拟变量
	gen byte ltc_0_2 = ltc_l0==1 |ltc_l1==1 |ltc_l2==1
	gen byte ltc_3_4 = ltc_l3==1 |ltc_l4==1
	label var ltc_0_2 "长护险试点后0-2期"
	label var ltc_3_4 "长护险试点后3-4期"
	global ltc_lag ltc_0_2 ltc_3_4
*医疗护理+生活照料类机构	
	reghdfe type_3 $ltc_lag $control , absorb(city_code year i.prov_code#c.year) vce(cluster city_code)
	sum   type_3    if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table3_panelB.doc",  keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)    replace   
	reghdfe nursing_home $ltc_lag $control , absorb(city_code year i.prov_code#c.year) vce(cluster city_code)
	sum   nursing_home      if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table3_panelB.doc",keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)  append   
*生活照料类机构		
	reghdfe type_6 $ltc_lag $control , absorb(city_code year i.prov_code#c.year) vce(cluster city_code)
	sum   type_6    if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table3_panelB.doc",  keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)    append   


*===========Table 4 Panel A=============*
*===========Table 4 Panel A=============*
*===========Table 4 Panel A=============*
*优先养老院待遇给付 Vs 居家和养老院待遇给付 
preserve
*松原市2018年制度发生变动，因此删除掉松原市2018年及之后的观测值
	drop if 市=="松原市" & year>=2018 
	forvalues i =  0(1)4 {
		gen ltc_n`i' =ltc_l`i' *treat_nursing
		gen ltc_hn`i' =ltc_l`i' *treat_home_nursing
	}
	gen byte ltc_n0_2 = ltc_n0==1| ltc_n1==1| ltc_n2==1
	gen byte ltc_n3_4 = ltc_n3==1| ltc_n4==1
	gen byte ltc_hn0_2 = ltc_hn0==1| ltc_hn1==1| ltc_hn2==1
	gen byte ltc_hn3_4 = ltc_hn3==1| ltc_hn4==1

*医疗类居家机构
	reghdfe type_3 ltc_n0_2 ltc_n3_4 ltc_hn0_2 ltc_hn3_4  $control   , absorb(city_code year i.prov_code#c.year) vce(cluster city_code) 
	sum   type_3    if LTC!=0
	outreg2 using "$table/table4_panelA.doc",  keep(ltc_n0_2 ltc_n3_4 ltc_hn0_2 ltc_hn3_4)  adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes ,Prov-Year,Yes)    replace    
*养老院	
	reghdfe nursing_home ltc_n0_2 ltc_n3_4 ltc_hn0_2 ltc_hn3_4 $control  , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code) 
	sum   nursing_home    if LTC!=0
	outreg2 using "$table/table4_panelA.doc",  keep(ltc_n0_2 ltc_n3_4 ltc_hn0_2 ltc_hn3_4)  adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes ,Prov-Year,Yes)    append    
restore


*===========Table4 Panel B=============*
*===========Table4 Panel B=============*
*===========Table4 Panel B=============*
*报销方式的影响：现金+服务 Vs 服务
preserve
	forvalues i = 0(1)4 {
		gen ltc_cash_`i' =ltc_l`i' 	 * treat_cash
		gen ltc_service_`i' =ltc_l`i' * treat_service
	}
	
	*现金+服务报销方式0-2期，3-4期的Dummy
	gen byte ltc_cash0_2 = ltc_cash_0==1 |ltc_cash_1==1 |ltc_cash_2==1
	gen byte ltc_cash3_4 = ltc_cash_3==1 |ltc_cash_4==1
	*服务报销方式0-2期，3-4期的Dummy
	gen byte ltc_service0_2 = ltc_service_0==1 |ltc_service_1==1 |ltc_service_2==1
	gen byte ltc_service3_4 = ltc_service_3==1 |ltc_service_4==1

	reghdfe type_3 ltc_cash0_2 ltc_cash3_4 ltc_service0_2 ltc_service3_4 $control   , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code) 
	sum   type_3      if LTC!=0
	outreg2 using "$table/table4_panelB.doc",  keep(ltc_cash0_2 ltc_cash3_4 ltc_service0_2 ltc_service3_4 )  adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes ,Prov-Year,Yes)    replace      
	
	reghdfe nursing_home ltc_cash0_2 ltc_cash3_4 ltc_service0_2 ltc_service3_4 $control  , absorb(city_code year i.prov_code#c.year) vce(cluster city_code) 
	sum   nursing_home      if LTC!=0
	outreg2 using "$table/table4_panelB.doc",  keep(ltc_cash0_2 ltc_cash3_4 ltc_service0_2 ltc_service3_4 )  adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes ,Prov-Year,Yes)    append    
restore
*===========Table4 Panel C=============*
*===========Table4 Panel C=============*
*===========Table4 Panel C=============*
*参保范围的影响：城镇职工 Vs 城镇职工+城乡居民
preserve 
*删掉制度设计发生变动的城市变动后的样本（上饶市2019年、日照市2020年发生变动）
	drop if 市=="上饶市" & year >=2019
	drop if 市=="日照市" & year >=2020

	bro ltc_l0 ltc_l1 ltc_l2 ltc_l3 ltc_l4 treat_ue treat_ueur
	forvalues i =  0(1)4 {
		gen ltc_ue`i' =ltc_l`i' *treat_ue
		gen ltc_ueur`i' =ltc_l`i' *treat_ueur
	}
	*城镇职工0-2期，3-4期的Dummy
	gen byte ltcue0_2 = ltc_ue0==1 |ltc_ue1==1 |ltc_ue2==1
	gen byte ltcue3_4 = ltc_ue3==1 |ltc_ue4==1 
	
	*城镇职工+城乡居民 0-2期，3-4期的Dummy
	gen byte ltcueur0_2 = ltc_ueur0==1 |ltc_ueur1==1 |ltc_ueur2==1
	gen byte ltcueur3_4 = ltc_ueur3==1 |ltc_ueur4==1 
	reghdfe type_3 ltcue0_2 ltcue3_4 ltcueur0_2 ltcueur3_4 $control   , absorb(city_code year i.prov_code#c.year  ) vce(cluster city_code) 
	outreg2 using "$table/table4_panelC.doc",  keep(ltcue0_2 ltcue3_4 ltcueur0_2 ltcueur3_4)  adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes ,Prov-Year,Yes )    replace      
	sum   type_3    if LTC!=0
	reghdfe nursing_home ltcue0_2 ltcue3_4 ltcueur0_2 ltcueur3_4  $control  , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code) 
	sum   nursing_home    if LTC!=0
	outreg2 using "$table/table4_panelC.doc",  keep(ltcue0_2 ltcue3_4 ltcueur0_2 ltcueur3_4)  adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes ,Prov-Year,Yes )    append    
restore 



*=========== Table5 =============*
*=========== Table5 =============*
*=========== Table5 =============*

	reghdfe type_3_p $ltc_lag $control , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code)
	sum   type_3_p    if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table5.doc",  keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)    replace   
	reghdfe type_3_np $ltc_lag $control , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code)
	sum   type_3_np    if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table5.doc",  keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)    append   
	reghdfe nursing_home_p $ltc_lag $control , absorb(city_code year i.prov_code#c.year) vce(cluster city_code)
	sum   nursing_home_p      if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table5.doc",keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)  append   
	reghdfe nursing_home_np $ltc_lag $control , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code)
	sum   nursing_home_np      if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/table5.doc",keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)  append   

*=========== Table6 =============*
*=========== Table6 =============*
*=========== Table6 =============*
*本表中额外控制了2010年城市特征与年份固定效应的交互项
	
	gen ltc_east=treat_event*east
	gen ltc_cent=treat_event*central
	gen ltc_west=treat_event*west
	reghdfe type_3 treat_event ltc_east   ltc_cent $control  , absorb(i.city_code i.year i.prov_code#c.year c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code)
	outreg2 using "$table/table6.doc",keep(treat_event ltc_east  ltc_cent) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) replace   
	
	reghdfe type_3_p treat_event ltc_east   ltc_cent $control  , absorb(i.city_code i.year i.prov_code#c.year c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code)
	outreg2 using "$table/table6.doc",keep(treat_event ltc_east  ltc_cent) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append   
	
	reghdfe type_3_np treat_event ltc_east   ltc_cent $control  , absorb(i.city_code i.year i.prov_code#c.year c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code)
	outreg2 using "$table/table6.doc",keep(treat_event ltc_east  ltc_cent) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append   
	
	reghdfe nursing_home treat_event ltc_east  ltc_cent $control  , absorb(i.city_code i.year i.prov_code#c.year c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code)
	outreg2 using "$table/table6.doc",keep(treat_event ltc_east  ltc_cent) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append    
	
	reghdfe nursing_home_p treat_event ltc_east  ltc_cent $control  , absorb(i.city_code i.year i.prov_code#c.year c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code)
	outreg2 using "$table/table6.doc",keep(treat_event ltc_east  ltc_cent) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append    
	
	reghdfe nursing_home_np treat_event ltc_east  ltc_cent $control  , absorb(i.city_code i.year i.prov_code#c.year c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code)
	outreg2 using "$table/table6.doc",keep(treat_event ltc_east  ltc_cent) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append    
	

*=========== Table7 =============*
*=========== Table7 =============*
*=========== Table7 =============*

*根据城市规模进行分类看相应的效应
*小城市：50万以下	
*中等城市：50万-100万
*大城市：100万-500万
	gen big =1 if pop_urban_2015 >100
	gen med =1 if pop_urban_2015 >50 &pop_urban_2015<=100
	gen sma =1 if pop_urban_2015<=50
	replace big=0 if big !=1
	replace med=0 if med !=1
	replace sma=0 if sma !=1
	replace big=. if pop_urban_2015==.
	replace sma=. if pop_urban_2015==.
	replace med=. if pop_urban_2015==.
	label var big "大城市"
	label var med "中等城市"
	label var sma "小城市"
*生成长护险和大小城市的交互项
	gen ltc_big=treat_event*big 
	gen ltc_med=treat_event*med
  	reghdfe type_3 treat_event ltc_big ltc_med $control   	, absorb(city_code year i.prov_code#c.year  c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code) 
	outreg2 using "$table/table7.doc",keep(treat_event ltc_big ltc_med) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) replace     
	reghdfe type_3_p treat_event ltc_big ltc_med $control   , absorb(city_code year i.prov_code#c.year  c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code) 
	outreg2 using "$table/table7.doc",keep(treat_event ltc_big ltc_med) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append     
	reghdfe type_3_np treat_event ltc_big ltc_med $control   , absorb(city_code year i.prov_code#c.year  c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code) 
	outreg2 using "$table/table7.doc",keep(treat_event ltc_big ltc_med) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append     
	reghdfe nursing_home treat_event ltc_big ltc_med $control   , absorb(city_code year i.prov_code#c.year  c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code) 
	outreg2 using "$table/table7.doc",keep(treat_event ltc_big ltc_med) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append      
	reghdfe nursing_home_p treat_event ltc_big ltc_med $control   , absorb(city_code year i.prov_code#c.year  c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code) 
	outreg2 using "$table/table7.doc",keep(treat_event ltc_big ltc_med) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append      
	reghdfe nursing_home_np treat_event ltc_big ltc_med $control   , absorb(city_code year i.prov_code#c.year  c.age80_ratio_2010#i.year c.sd_ratio_2010#i.year c.unhealth_ratio_2010#i.year) vce(cluster city_code) 
	outreg2 using "$table/table7.doc",keep(treat_event ltc_big ltc_med) adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,basechar_YearFE,Yes) append      



*===============附录II-表II1===============*
*===============附录II-表II1===============*
*===============附录II-表II1===============*
*第1、2、3列结果
	reghdfe n_type_3 $ltc_lag $control , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code)
	sum   n_type_3    if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/app_II1.doc",  keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)   replace   
	reghdfe n_nursing_home $ltc_lag $control , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code)
	sum   n_nursing_home      if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/app_II1.doc",keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)  append   
	reghdfe n_type_6 $ltc_lag $control , absorb(city_code year i.prov_code#c.year) vce(cluster city_code)
	sum   n_type_6    if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/app_II1.doc",  keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)   append   

*第4列结果
*将敬老院、护理院、福利院纳入养老院的覆盖范围
	reghdfe nursing_home_1 $ltc_lag  $control  , absorb(city_code year i.prov_code#c.year )  vce(cluster city_code)
	sum   nursing_home_1      if LTC!=0
	local  meany= round(r(mean),0.001)
	outreg2 using "$table/app_II1.doc",keep($ltc_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes)  append   


*========附录III 表III1 控制其他政策的影响==========*
*========附录III 表III1 控制其他政策的影响==========*
*========附录III 表III1 控制其他政策的影响==========*
*生成居家社区综合改革试点0-2期、3-4期Dummy
	gen byte jj_0_2 = home_l0==1 |home_l1==1 |home_l2==1
	gen byte jj_3_4 = home_l3==1 |home_l4==1
	global jj_lag jj_0_2 jj_3_4
	reghdfe type_3 $ltc_lag $jj_lag $control , absorb(city_code year i.prov_code#c.year) vce(cluster city_code)
	sum   type_3    if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/app_III1.doc",  keep($ltc_lag $jj_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,type,home)    replace     
	reghdfe type_6 $ltc_lag $jj_lag $control , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code)
	sum   type_6    if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/app_III1.doc",  keep($ltc_lag $jj_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,type,home)    append   
	reghdfe nursing_home $ltc_lag $jj_lag $control , absorb(city_code year i.prov_code#c.year ) vce(cluster city_code)
	sum   nursing_home    if LTC!=0
    local  meany= round(r(mean),0.001)
	outreg2 using "$table/app_III1.doc",  keep($ltc_lag $jj_lag)  adjr2  bdec(3) addtext(Mean Y T,`meany',City FE,Yes,Year FE,Yes,City Control,Yes,Prov-Year,Yes,type,home)    append   


