/*======================================================*
Purpose 	:	附录异质性稳健估计结果
Data 1		: 	城市层面老年照护机构信息数据
Data 2		: 	长护险制度特征数据
Data 3		: 	城市统计年鉴数据
Created by	:	张毅 zhangyieco@gmail.com
Last Modify : 	20241026
*=======================================================*/
	
	clear all
	capture log close
	set	more off
	set scrollbufsize 2048000


	global replication "/Users/zhangyi/Desktop/replication"	
	global rawdata  "$replication/rawdata"
	global workingdata  "$replication/workingdata"
	global table  "$replication/output/table"
	global figure  "$replication/output/figure"
	cd "$replication" 


	use "$rawdata/TYC_2020_reg.dta",clear
	
	xtset city_code year

	*生成事件时间点
	gen event =year - ltc_time
	tab event,m
	bro 市 year ltc_time event

	replace event = -7 if event <= -7
	replace event = 4 if event >=4 & event!=.
	tab event,m


	tab event, gen(ltc_)
	forvalues i = 1/12{
		replace ltc_`i' = 0 if ltc_`i' == .
	}

	label var ltc_1 "<=-7" 
	label var ltc_2 "-6" 
	label var ltc_3 "-5" 
	label var ltc_4 "-4" 
	label var ltc_5 "-3" 
	label var ltc_6 "-2" 
	label var ltc_7 "-1" 
	label var ltc_8 "0" 
	label var ltc_9 "1" 
	label var ltc_10 "2" 
	label var ltc_11 "3" 
	label var ltc_12 ">=4" 
	rename ltc_1 ltc_p7
	rename ltc_2 ltc_p6
	rename ltc_3 ltc_p5
	rename ltc_4 ltc_p4
	rename ltc_5 ltc_p3
	rename ltc_6 ltc_p2
	rename ltc_7 ltc_p1
	rename ltc_8 ltc_l0
	rename ltc_9 ltc_l1
	rename ltc_10 ltc_l2
	rename ltc_11 ltc_l3
	rename ltc_12 ltc_l4
	global ltc_all ltc_p7 ltc_p6 ltc_p5 ltc_p4 ltc_p3 ltc_p2 ltc_p1 ltc_l0 ltc_l1 ltc_l2 ltc_l3 ltc_l4


	*控制变量
	global control pop GDP yszc hospital hospital_bed doctor prov_old_ratio


*===============附录II-表II2: Goodman-Bacon分解===============*
*===============附录II-表II2: Goodman-Bacon分解===============*
*===============附录II-表II2: Goodman-Bacon分解===============*
*ssc install ddtiming,replace 
	h ddtiming
preserve 
 	duplicates tag 市, generate(a)
	tab a,m
	keep if a==10 //需使用平衡面板
	*附录表 II2 
	ddtiming type_3 treat_event ,i(city_code) t(year)
	*附录表 II3
	ddtiming nursing_home treat_event ,i(city_code) t(year)
restore

* ssc install stackedev			,replace 
* ssc install did_imputation	,replace 
* ssc install csdid 			,replace 
* ssc install did_multiplegt_dyn,replace 

*=====Cengiz et al. (2019)======*
*=====Cengiz et al. (2019)======*
*=====Cengiz et al. (2019)======*
preserve
	gen no_treat=LTC==0
	label variable no_treat "Never Treated"
	replace ltc_p1=0
*医疗类居家机构
	stackedev type_3 $ltc_all , cohort(ltc_time) time(year ) never_treat(no_treat) unit_fe(city_code) clust_unit(city_code) covariates($control i.prov_code#c.year)
	estimates store Cengiz_3
*养老院	
	stackedev nursing_home $ltc_all , cohort(ltc_time) time(year ) never_treat(no_treat) unit_fe(city_code) clust_unit(city_code) covariates($control i.prov_code#c.year)
	estimates store Cengiz_n
restore


*=====Borusyak et al.(2021)======*
*=====Borusyak et al.(2021)======*
*=====Borusyak et al.(2021)======*
*医疗类居家机构
did_imputation type_3 市 year ltc_time, horizons(0 1 2 3)  pretrend(7) 
est sto type3_impu
*养老院
did_imputation nursing_home 市 year ltc_time, horizons(0 1 2 3)  pretrend(7) 
est sto nursing_impu

*=====Callaway and Sant'Anna ====*
*=====Callaway and Sant'Anna ====*
*=====Callaway and Sant'Anna ====*

preserve
gen gvar = ltc_time
recode gvar (. = 0)
*医疗类居家机构
csdid type_3, ivar(city_code) time(year) gvar(gvar) notyet  
estat event, window(-7 4) estore(csdd_type3) 
*养老院
csdid nursing_home, ivar(city_code) time(year) gvar(gvar) notyet  
estat event, window(-7 4) estore(csdd_nursing) 
restore


*****************************************
*** DeChaisemartin and D'Haultfeuille ***
*****************************************
preserve
*医疗类居家机构
did_multiplegt_dyn type_3 city_code year treat_event, effects(4) placebo(4) cluster(city_code)
matrix define mat_1_type3=e(estimates)
matrix define mat_2_type3=e(variances)

*养老院
did_multiplegt_dyn nursing_home city_code year treat_event, effects(4) placebo(4) cluster(city_code)
matrix define mat_1_nursing=e(estimates)
matrix define mat_2_nursing=e(variances)
restore


*=====稳健估计量的汇总======*
*=====稳健估计量的汇总======*
*=====稳健估计量的汇总======*



event_plot  Cengiz_3 type3_impu csdd_type3 mat_1_type3#mat_2_type3, ///
	stub_lag(ltc_l# tau# Tp# Effect_#) ///
	stub_lead( ltc_p# pre# Tm# Placebo_#)  ///
	together trimlag(4) trimlead(7) noautolegend plottype(scatter) ciplottype(rcap) ///
	graph_opt(bgcolor(white) plotregion(color(white)) graphregion(color(white)) ///
	legend(order(1 "Cengiz et al (2019)"  3 "Borusyak et al (2021)" 5 "Callaway and Sant’Anna (2021)" 7 "Chaisemartin and D’Haultfoeuille (2024)") ring(0)  pos(11) row(5)  ) ///
	ytitle("估""计""系""数",size(9pt) angle(90) orientation(horizontal)) title("长护险对医疗类居家机构的影响",size(10pt) color(black)) ///
	xscale(r(-7.5 4.5)) xtick(-7(1)4) xlabel( -7 -6 -5 -4 -3 -2 -1 0 1 2 3 4  , labsize(small)) xline(-1.25(.01)-0.75, lcolor(gs14))  ///
	ylabel(, grid) xtitle("", height(6) size(small))  )  ///
	lag_opt1(msymbol(S) mcolor(black)  msize(1.2) mlwidth(0.3)) lead_opt1(msymbol(S) mcolor(black) msize(1.2) mlwidth(0.3)) lag_ci_opt1(lcolor(black) lwidth(0.15) ) lead_ci_opt1(lcolor(black) lwidth(0.15) ) ///
	lag_opt2(msymbol(T) mcolor(black)  msize(1.2) mlwidth(0.3)) lead_opt2(msymbol(T) mcolor(black) msize(1.2) mlwidth(0.3)) lag_ci_opt2(lcolor(black) lwidth(0.15) ) lead_ci_opt2(lcolor(black) lwidth(0.15) )  ///
	lag_opt3(msymbol(O) mcolor(black)  msize(1.2) mlwidth(0.3)) lead_opt3(msymbol(O) mcolor(black) msize(1.2) mlwidth(0.3)) lag_ci_opt3(lcolor(black) lwidth(0.15) ) lead_ci_opt3(lcolor(black) lwidth(0.15) )  ///
	lag_opt4(msymbol(lgx) mcolor(black) msize(1.2) mlwidth(0.3))  lead_opt4(msymbol(lgx) mcolor(black) msize(1.2) mlwidth(0.3)) lag_ci_opt4(lcolor(black) lwidth(0.15) ) lead_ci_opt4(lcolor(black) lwidth(0.15) )  ///
	perturb(-0.3(0.15)0.35)

	graph save "$figure/Appendix_C1.gph",replace 


event_plot   Cengiz_n nursing_impu csdd_nursing mat_1_nursing#mat_2_nursing, ///
	stub_lag(ltc_l# tau# Tp# Effect_#) ///
	stub_lead( ltc_p# pre# Tm# Placebo_#)  ///
	together trimlag(4) trimlead(7) noautolegend plottype(scatter) ciplottype(rcap) ///
	graph_opt(bgcolor(white) plotregion(color(white)) graphregion(color(white)) ///
	legend(order(1 "Cengiz et al (2019)"  3 "Borusyak et al (2021)" 5 "Callaway and Sant’Anna (2021)" 7 "Chaisemartin and D’Haultfoeuille (2024)") ring(0)  pos(11) row(5)  ) ///
	ytitle("估""计""系""数",size(9pt) angle(90) orientation(horizontal)) title("长护险对养老院的影响",size(10pt) color(black)) ///
	xscale(r(-7.5 4.5)) xtick(-7(1)4) xlabel( -7  -6 -5 -4 -3 -2 -1 0 1 2 3 4  , labsize(small)) xline(-1.25(.01)-0.75, lcolor(gs14))  ///
	ylabel(0(50)100, grid) xtitle("", height(6) size(small))  )  ///
	lag_opt1(msymbol(S) mcolor(black)  msize(1.2) mlwidth(0.3)) lead_opt1(msymbol(S) mcolor(black) msize(1.2) mlwidth(0.3)) lag_ci_opt1(lcolor(black) lwidth(0.15) ) lead_ci_opt1(lcolor(black) lwidth(0.15) ) ///
  	lag_opt2(msymbol(T) mcolor(black)  msize(1.2) mlwidth(0.3)) lead_opt2(msymbol(T) mcolor(black) msize(1.2) mlwidth(0.3)) lag_ci_opt2(lcolor(black) lwidth(0.15) ) lead_ci_opt2(lcolor(black) lwidth(0.15) )  ///
	lag_opt3(msymbol(O) mcolor(black)  msize(1.2) mlwidth(0.3)) lead_opt3(msymbol(O) mcolor(black) msize(1.2) mlwidth(0.3)) lag_ci_opt3(lcolor(black) lwidth(0.15) ) lead_ci_opt3(lcolor(black) lwidth(0.15) )  ///
	lag_opt4(msymbol(lgx) mcolor(black) msize(1.2) mlwidth(0.3))  lead_opt4(msymbol(lgx) mcolor(black) msize(1.2) mlwidth(0.3)) lag_ci_opt4(lcolor(black) lwidth(0.15) ) lead_ci_opt4(lcolor(black) lwidth(0.15) )  ///
	perturb(-0.3(0.15)0.35)
	graph save "$figure/Appendix_C2.gph",replace 

