
/*======================================================*
Purpose 	:	安慰剂检验
Data 1		: 	城市层面老年照护机构信息数据
Data 2		: 	长护险制度特征数据
Data 3		: 	城市统计年鉴数据
Created by	:	张毅 zhangyieco@gmail.com
Last Modify : 	20241023
*=======================================================*/
	clear all
	set	more off
	set scrollbufsize 2048000
	capture log close 


	global replication "/Users/zhangyi/Desktop/replication"	
	global rawdata  "$replication/rawdata"
	global workingdata  "$replication/workingdata"
	global table  "$replication/output/table"
	global figure  "$replication/output/figure"
	cd "$replication" 

*绘图命令
	*ssc install dpplot,replace 
*保存系数
	*ssc install parmest,replace 

*安慰剂检验
*生成安慰剂检验的结果存储数据，运行一次后通过注释隐藏
	clear
	gen parm =""
	gen estimate =.
	gen stderr =.
	gen dof =.
	gen t =.
	gen p =.
	gen min95 =.
	gen max95=.
	save "$workingdata/placebotest/simulations_home.dta",replace 
	save "$workingdata/placebotest/simulations_nursinghome.dta",replace 


	use "$rawdata/TYC_2020_reg.dta",clear	
	xtset city_code year
	
	save "$workingdata/placebotest/placebo.dta",replace 

	global control pop GDP yszc hospital hospital_bed doctor prov_old_ratio

clear all 
forvalue i=1(1)500 {
	use "$workingdata/placebotest/placebo.dta",clear 
	scalar define lowest_time=2010
	scalar define highest_time=2020
	sort 市 year 
	bys 市 :gen n=_n

	gen fake_time=(lowest_time +int((highest_time-lowest_time+1)*runiform())) if n==1
	tab fake_time,m
	gen x=(ltc_time==fake_time) if n==1
	summarize x, meanonly

	while r(mean)>0 {
	replace fake_time=(lowest_time +int((highest_time-lowest_time+1)*runiform())) if n==1 & x==1
	cap drop x
	gen x=(ltc_time==fake_time) if n==1
	summarize x, meanonly
	}
	drop x
	replace fake_time=fake_time[_n-1] if fake_time==.
	gen fake_did=(year>fake_time)

preserve
	capture reghdfe type_3 fake_did LTC $control , absorb(city_code year i.prov_code#c.year)  vce(cluster city_code)
	parmest,format(estimate min95 max95 %8.2f p %8.3f) saving("$workingdata/placebotest/home.dta", replace)
	use "$workingdata/placebotest/home.dta",clear 
	keep if parm=="fake_did"
	append using "$workingdata/placebotest/simulations_home.dta"
	save "$workingdata/placebotest/simulations_home.dta",replace 
restore		

preserve
	capture reghdfe nursing_home fake_did  LTC $control , absorb(city_code year i.prov_code#c.year)  vce(cluster city_code)
	parmest,format(estimate min95 max95 %8.2f p %8.3f) saving("$workingdata/placebotest/nursing.dta", replace)
	use "$workingdata/placebotest/nursing.dta",clear 
	keep if parm=="fake_did"
	append using "$workingdata/placebotest/simulations_nursinghome.dta"
	save "$workingdata/placebotest/simulations_nursinghome.dta",replace 
restore		
	display "第`i'次安慰剂检验"
	display "第`i'次安慰剂检验"
	display "第`i'次安慰剂检验"
}



*医疗类居家机构安慰剂检验绘图
	use "$workingdata/placebotest/simulations_home.dta", clear
	keep if parm=="fake_did" 
	#delimit ;
	dpplot estimate, xline(0, lc(black*0.5) lp(solid)) xline(2.262, lp(solid) lc(black))
	             xtitle("系数", size(*0.8)) 
	             xlabel(-1(1)3, format(%4.1f) labsize(small))
	             ytitle("频率", size(*0.8)) title("安慰剂检验-医疗类居家机构", size(*0.8)) 
	             ylabel(, grid format(%4.1f) labsize(small)) 
	             note("") caption("") mc("0 96 39") 
	             graphregion(fcolor(white)) mcolor(navy);
	#delimit cr
	graph save "$figure/Appendix_D1.gph", replace

*养老院安慰剂检验绘图
	use "$workingdata/placebotest/simulations_nursinghome.dta", clear
	keep if parm=="fake_did" 
	#delimit ;
	dpplot estimate, xline(0, lc(black*0.5) lp(solid)) xline(6.262, lp(solid) lc(black))
	             xtitle("系数", size(*0.8))  
	             xlabel(-3(1)7, format(%4.1f) labsize(small))
	             ytitle("频率", size(*0.8)) title("安慰剂检验-养老院", size(*0.8)) 
	             ylabel(, grid format(%4.1f) labsize(small)) 
	             note("") caption("") mc("0 96 39") 
	             graphregion(fcolor(white)) mcolor(navy) ;
	#delimit cr
	graph save "$figure/Appendix_D2.gph", replace












